@@ -1,11 +1,11 @@
 #' Appendix Dictionary
 #' @description A function designed to create post-hoc dictionaries in the
 #' \code{\link{SemNetDictionaries}} package. This allows for new semantic categories or word lists
-#' to be saved for future use. THIS IS YOUR OWN PERSONAL DICTIONARY.
+#' to be saved for future use (i.e., your own perosnality dictionary).
 #' Dictionaries created using this function can either be saved as an R object to your global
 #' environment or as a .rds file on your current computer. Open-source community-derived
 #' dictionaries can be uploaded to and downloaded from
-#' \href{AlexChristensen/SemNetDictionaries}{https://github.com/AlexChristensen/SemNetDictionaries}
+#' \href{https://github.com/AlexChristensen/SemNetDictionaries}{https://github.com/AlexChristensen/SemNetDictionaries}
 #' 
 #' @param ... Character vector.
 #' A vector of words to create or add to a dictionary
@@ -14,26 +14,32 @@
 #' Name of dictionary to create or add words to.
 #' Defaults to \code{"appendix"}.
 #' Input a name to create or add to an existing dictionary.
-#' This function with automaticaly name files with the \code{"*.dictionary.rds"} suffix.
+#' This function with automaticaly name files with the \code{"*.dictionary.rds"} suffix
 #' 
 #' @param save.location Character.
 #' A choice for where to store appendix dictionary.
 #' Defaults to \code{"envir"}.
 #' 
-#' \code{"envir"} will return dictionary as a vector object
-#' to R's global environment
+#' \itemize{
 #' 
-#' \code{"choose"} allows you to choose a directory for
-#' more permenant storage. This will allow you to use this dictionary
-#' in the future
+#' \item{\code{"envir"}:}
+#' {Returns dictionary as a vector object to \code{R}'s global environment}
 #' 
-#' \code{"path"} allows you to specify a path to a directory
-#' if it is already known. This will allow direct updates to the directory
-#' and bypass the prompts in the save/update menus. This will also
-#' allow you to use this dictionary in the future
+#' \item{\code{"choose"}:}
+#' {User chooses a directory for more permenant storage. This will
+#' allow you to use this dictionary in the future}
+#' 
+#' \item{\code{"path"}:}
+#' {User specifies a path to a directory if it is already known. This
+#' will allow direct updates to the directory and bypass the prompts in
+#' the save/update menus. This will also allow you to use
+#' this dictionary in the future}
+#' 
+#' }
 #' 
 #' @param path Character.
-#' A path to an existing directory
+#' A path to an existing directory.
+#' Only necessary for \code{save.location = "path"}
 #' 
 #' @details Appendix dictionaries are useful for storing spelling
 #' definitions that are not available in the \code{\link{SemNetDictionaries}}
@@ -47,25 +53,36 @@
 #' save or update your dictionary.
 #' You have two options:
 #' 
-#' \code{No} (or \code{2}) will not give this function permission to save
-#' your dictionary to your computer. \code{save.location = "envir"} will
-#' always return your dictionary as a vector object to \code{R}'s
-#' global environment
+#' \itemize{
 #' 
-#' \code{Yes} (or \code{1}) will give this function permission to
+#' \item{\code{Yes} (or \code{1}):}
+#' {Gives this function permission to
 #' save (or update) your dictionary to a chosen directory.
 #' If \code{save.location = "envir"}, your file will
-#' be deleted after closing \code{R} (unless manually saved).
+#' be deleted after closing \code{R}}
+#' 
+#' \item{\code{No} (or \code{2}):}
+#' {Does NOT give this function permission to save
+#' your dictionary to your computer. \code{save.location = "envir"} will
+#' always return your dictionary as a vector object to \code{R}'s
+#' global environment}
+#' 
+#' }
 #' 
 #' To save your dictionary file, you can either:
 #' 
-#' Manually save: use \link{saveRDS} and save using the \code{"*.dictionary"} suffix
+#' \itemize{
 #' 
-#' \code{save.location = "choose"}: a file explorer menu will pop-up and a directory
-#' can be selected
+#' \item{Manually save:}
+#' {Use \link{saveRDS} and save using the \code{"*.dictionary"} suffix}
 #' 
-#' \code{save.location = "path"}: the file will automatically be saved to the directory
-#' you provide
+#' \item{\code{save.location = "choose"}:}
+#' {A file explorer menu will pop-up and a directory can be manually selected}
+#' 
+#' \item{\code{save.location = "path"}:}
+#' {The file will automatically be saved to the directory you provide}
+#' 
+#' }
 #' 
 #' Note that \code{save.location = "choose"} and \code{save.location = "path"} will
 #' automatically update your dictionary if there is a file with the same name enter
@@ -78,11 +95,11 @@
 #' transferred to other computers in order to use them elsewhere.
 #' If you would like to share a dictionary for others to use, then please submit
 #' a pull request or post an issue with your dictionary on my GitHub:
-#' \href{AlexChristensen/SemNetDictionaries}{https://github.com/AlexChristensen/SemNetDictionaries}.
+#' \href{https://github.com/AlexChristensen/SemNetDictionaries}{AlexChristensen/SemNetDictionaries}.
 #' 
 #' @examples
 #' #create a dictionary
-#' new.dictionary <- append.dictionary(c("words","are","fun"))
+#' new.dictionary <- append.dictionary(c("words","are","fun"), save.location = "envir")
 #' 
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
@@ -185,7 +202,7 @@ append.dictionary <- function(...,
             if(ans == 1)
             {
                 #save as updated appendix dictionary
-                saveRDS(append.words, file = paste(sav.loc,append.data,sep="\\"))
+                saveRDS(append.words, file = file.path(paste(sav.loc,append.data,sep="\\")))
                 
                 #let user know that the dictionary has been updated
                 message(paste(append.data," has been updated.",sep=""))
@@ -199,7 +216,7 @@ append.dictionary <- function(...,
         }else if(save.location == "path")
         {
             #then save as updated appendix dictionary
-            saveRDS(append.words, file = paste(sav.loc,append.data,sep="\\"))
+            saveRDS(append.words, file = file.path(paste(sav.loc,append.data,sep="\\")))
             
             #let user know that the dictionary has been updated
             message(paste(append.data," has been updated.",sep=""))
@@ -223,12 +240,12 @@ append.dictionary <- function(...,
         }else if(save.location == "choose")
         {
             #ask if user would like to save dictionary
-            ans <- menu(c("Yes","No"),title="Would you like to save dictionary?")
+            ans <- menu(c("Yes","No"),title="Would you like to save your appendix dictionary?")
             
             if(ans == 1)
             {
                 #save as new appendix dictionary
-                saveRDS(append.words, file = paste(sav.loc,append.data,sep="\\"))
+                saveRDS(append.words, file = file.path(paste(sav.loc,append.data,sep="\\")))
                 
                 #let user know that a new file has been saved
                 message(paste("A new dictionary file was created in:\n",
@@ -243,7 +260,7 @@ append.dictionary <- function(...,
         }else if(save.location == "path")
         {
             #save as new appendix dictionary
-            saveRDS(append.words, file = paste(sav.loc,append.data,sep="\\"))
+            saveRDS(append.words, file = file.path(paste(sav.loc,append.data,sep="\\")))
             
             #let user know that a new file has been saved
             message(paste("A new dictionary file was created in:\n",
